@@ -1,6 +1,6 @@
 package XTaTIK::Controller::Root;
 
-our $VERSION = '0.004001'; # VERSION
+our $VERSION = '0.005001'; # VERSION
 
 use Mojo::Base 'Mojolicious::Controller';
 use XTaTIK::Common qw/n_to_br  set_product_pic/;
@@ -26,7 +26,8 @@ sub products_category {
     @$products or $self->reply->not_found;
 
     for ( @$products ) {
-        set_product_pic( $self, @$_{qw/image number/} ) for $_->{contents}->@*;
+        set_product_pic( $self, @$_{qw/image number/} ) for
+            grep exists $_->{number}, $_->{contents}->@*;
     }
 
     $self->stash(
